<?php
/**
 * @file
 * Recording classes for Zoom API.
 *
 * @see https://zoom.github.io/api/#cloud-recording
 */

/**
 * Zoom API Recording Class.
 */
class ZoomAPIRecording extends ZoomAPI {

  /**
   * List Recordings.
   *
   * @param string $host_zoom_user_id
   *   The meeting host zoom user ID.
   * @param string $meeting_id
   *   The (optional) meeting number.
   * @param string $from
   *   The meeting start time after this date, MM/dd/yyyy hh:mm a. For example:
   *   11/05/2014 09:05 pm. Use the host’s time zone, if host has not set time
   *   zone, will use GMT.
   * @param string $to
   *   The meeting start time before this date, MM/dd/yyyy hh:mm a.
   * @param int $page_size
   *   The amount of records returns within a single API call. Defaults to 30.
   *   Max of 300 meetings.
   * @param int $page_number
   *   Current page number of returned records. Default to 1.
   *
   * @return array
   *   An array of cloud recording meetings.
   */
  public function list($host_zoom_user_id, $meeting_id = '', $from = '', $to = '', $page_size = 30, $page_number = 1) {
    $options['host_id'] = $host_zoom_user_id;
    $options['meeting_id'] = $meeting_id;
    $options['from'] = $from;
    $options['to'] = $to;
    $options['page_size'] = $page_size;
    $options['page_number'] = $page_number;
    return $this->sendRequest('recording/list', $options);
  }

  /**
   * Get Recording.
   *
   * @param string $meeting_id
   *   The zoom meeting ID.
   *
   * @return array
   *   The meeting recording information.
   *
   * @todo Appears this is looking for the uuid which is not what the docs
   * describe.
   */
  public function get($meeting_id) {
    $options['meeting_id'] = $meeting_id;
    return $this->sendRequest('recording/get', $options);
  }
}
